16.163. cdist-type__xymon_client(7) — cdist 6.9.4 documentation

# 16.163. cdist-type__xymon_client(7)

## 16.163.1. NAME

cdist-type__xymon_client - Install the Xymon client

## 16.163.2. DESCRIPTION

This cdist type installs the Xymon client and configures it to report with FQDN.

## 16.163.3. REQUIRED PARAMETERS

None.

## 16.163.4. OPTIONAL PARAMETERS

state

  'present', 'absent', defaults to 'present'.

servers

  One or more IP addresses (space separated) of the Xymon server(s) to report to. While DNS-names are ok it is discouraged, defaults to 127.0.0.1.

## 16.163.5. BOOLEAN PARAMETERS

msgcache

  Enable xymon msgcache. Note: XYMONSERVER has to be 127.0.0.1 for using msgcache (see msgcache (8) of the xymon documentation for details).

## 16.163.6. EXAMPLES

    # minimal, report to 127.0.0.1
    __xymon_client

    # specify server:
    __xymon_client --servers "192.168.1.1"

    # activate `msgcache` for passive client:
    __xymon_client --msgcache

## 16.163.7. SEE ALSO

cdist__xymon_server(7), xymon(7), msgcache(8)

## 16.163.8. AUTHORS

Thomas Eckert <tom--@--it-eckert.de>

## 16.163.9. COPYING

Copyright (C) 2018-2019 Thomas Eckert. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.